cosinnus.core.decorators package
================================

Submodules
----------

cosinnus.core.decorators.views module
-------------------------------------

.. automodule:: cosinnus.core.decorators.views
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cosinnus.core.decorators
    :members:
    :undoc-members:
    :show-inheritance:
